@@ -1,12 +1,9 @@
-use std::fmt::{Debug, LowerHex, Formatter, UpperHex};
 use super::bits::Bits;
+use crate::core::bits::bit_cast;
 use num_bigint::{BigInt, Sign};
 use num_traits::cast::ToPrimitive;
+use std::fmt::{Debug, Formatter, LowerHex, UpperHex};
 use std::num::Wrapping;
-use num_traits::Zero;
-use crate::core::shortbitvec::ShortBitVec;
-use crate::core::bits::bit_cast;
-
 
 #[derive(Clone, Debug, Copy, PartialEq, Default)]
 pub struct Signed<const N: usize>(Bits<N>);
@@ -26,16 +23,16 @@ impl<const N: usize> UpperHex for Signed<N> {
 impl<const N: usize> Signed<N> {
     pub fn min() -> BigInt {
         // Largest negative value is 1000...0 for N bits
-        let mut ret = -Self::max() - 1;
+        let ret = -Self::max() - 1;
         ret
     }
     pub fn max() -> BigInt {
         // Largest positive value is 0111...1 for N bits
         // Which is 2^N-1
-        BigInt::from(2).pow((N-1) as u32) - 1
+        BigInt::from(2).pow((N - 1) as u32) - 1
     }
     pub fn sign_bit(&self) -> bool {
-        self.0.get_bit(N-1)
+        self.0.get_bit(N - 1)
     }
     pub fn bigint(&self) -> BigInt {
         let mut ret = BigInt::default();
@@ -63,7 +60,7 @@ impl<const N: usize> Signed<N> {
 }
 
 impl<const N: usize> From<BigInt> for Signed<N> {
-    fn from(mut x: BigInt) -> Self {
+    fn from(x: BigInt) -> Self {
         assert!(x.bits() <= N as u64);
         if N <= 32 {
             if x.sign() == Sign::Minus {
@@ -86,9 +83,7 @@ impl<const N: usize> std::ops::Neg for Signed<N> {
 
     fn neg(self) -> Self::Output {
         Signed(match self.0 {
-            Bits::Short(x) => {
-                Bits::Short((Wrapping(0_u32)-Wrapping(x.short())).0.into())
-            }
+            Bits::Short(x) => Bits::Short((Wrapping(0_u32) - Wrapping(x.short())).0.into()),
             Bits::Long(x) => {
                 let mut val = [false; N];
                 for ndx in 0..N {
@@ -111,7 +106,9 @@ impl<const N: usize> std::ops::Add<Signed<N>> for Signed<N> {
 impl<const N: usize> std::ops::Sub<Signed<N>> for Signed<N> {
     type Output = Signed<N>;
 
-    fn sub(self, rhs: Signed<N>) -> Self::Output {Self(self.0 - rhs.0)}
+    fn sub(self, rhs: Signed<N>) -> Self::Output {
+        Self(self.0 - rhs.0)
+    }
 }
 
 impl std::ops::Mul<Signed<16>> for Signed<16> {
@@ -122,7 +119,6 @@ impl std::ops::Mul<Signed<16>> for Signed<16> {
     }
 }
 
-
 impl<const N: usize> From<i32> for Signed<N> {
     fn from(x: i32) -> Self {
         if x > 0 {
@@ -160,10 +156,9 @@ pub fn unsigned_bit_cast<const M: usize, const N: usize>(x: Signed<N>) -> Bits<M
 
 #[cfg(test)]
 mod tests {
-    use crate::core::signed::{Signed, signed_bit_cast, unsigned_bit_cast};
     use crate::core::bits::Bits;
+    use crate::core::signed::{signed_bit_cast, unsigned_bit_cast, Signed};
     use num_bigint::BigInt;
-    use num_traits::ToPrimitive;
 
     #[test]
     fn test_min_range_correct() {
@@ -206,13 +201,12 @@ mod tests {
         run_import_tests::<34>(1 << 16);
     }
 
-
     #[test]
     fn time_adds_bigint() {
         let now = std::time::Instant::now();
-        for iter in 0..10 {
+        for _iter in 0..10 {
             let mut q = BigInt::from(0_u32);
-            for i in 0..1_000_000 {
+            for _i in 0..1_000_000 {
                 q = q + 1;
             }
         }
@@ -223,9 +217,9 @@ mod tests {
     #[test]
     fn time_adds_bitvec() {
         let now = std::time::Instant::now();
-        for iter in 0..10 {
+        for _iter in 0..10 {
             let mut q = Bits::<40>::from(0_u32);
-            for i in 0..1_000_000 {
+            for _i in 0..1_000_000 {
                 q = q + 1_usize;
             }
         }
@@ -236,9 +230,9 @@ mod tests {
     #[test]
     fn time_adds_bitvec_small() {
         let now = std::time::Instant::now();
-        for iter in 0..10 {
+        for _iter in 0..10 {
             let mut q = Bits::<16>::from(0_u32);
-            for i in 0..1_000_000 {
+            for _i in 0..1_000_000 {
                 q = q + 1_usize;
             }
         }
@@ -254,14 +248,14 @@ mod tests {
     #[test]
     fn test_signed_cast() {
         let x = Signed::<16>::from(-23);
-        let y : Signed<40> = signed_bit_cast(x);
+        let y: Signed<40> = signed_bit_cast(x);
         assert_eq!(y, Signed::<40>::from(-23));
     }
 
     #[test]
     fn test_unsigned_cast() {
         let x = Signed::<16>::from(-23);
-        let y : Bits<16> = unsigned_bit_cast(x);
+        let y: Bits<16> = unsigned_bit_cast(x);
         assert_eq!(y, Bits::<16>::from(0xFFe9_usize))
     }
 
@@ -275,7 +269,6 @@ mod tests {
         assert_eq!(x.bigint(), BigInt::from(23));
     }
 
-
     #[test]
     fn test_neg_operator_larger() {
         let t: BigInt = BigInt::from(23) << 32;
@@ -286,5 +279,4 @@ mod tests {
         let x = -x;
         assert_eq!(x.bigint(), t.clone());
     }
-
-}
\ No newline at end of file
+}
