@@ -2,7 +2,7 @@ use rand::Rng;
 use rust_hdl::core::prelude::*;
 use rust_hdl::hls::prelude::*;
 
-#[derive(LogicBlock, Default)]
+#[derive(LogicBlock)]
 struct HostTest {
     pc_to_host: SyncFIFO<Bits<8>, 3, 4, 1>,
     host_to_pc: SyncFIFO<Bits<8>, 3, 4, 1>,
@@ -16,11 +16,34 @@ struct HostTest {
     pub sys_clock: Signal<In, Clock>,
 }
 
+impl Default for HostTest {
+    fn default() -> Self {
+        Self {
+            pc_to_host: Default::default(),
+            host_to_pc: Default::default(),
+            bidi_dev: Default::default(),
+            host: Default::default(),
+            bridge: Bridge::new(["port", "iport", "fport"]),
+            port: Default::default(),
+            iport: Default::default(),
+            fport: Default::default(),
+            bidi_clock: Default::default(),
+            sys_clock: Default::default(),
+        }
+    }
+}
+
 impl Logic for HostTest {
     #[hdl_gen]
     fn update(&mut self) {
-        FIFOReadController::<Bits<8>>::join(&mut self.bidi_dev.data_to_bus, &mut self.pc_to_host.bus_read);
-        FIFOWriteController::<Bits<8>>::join(&mut self.bidi_dev.data_from_bus, &mut self.host_to_pc.bus_write);
+        FIFOReadController::<Bits<8>>::join(
+            &mut self.bidi_dev.data_to_bus,
+            &mut self.pc_to_host.bus_read,
+        );
+        FIFOWriteController::<Bits<8>>::join(
+            &mut self.bidi_dev.data_from_bus,
+            &mut self.host_to_pc.bus_write,
+        );
         self.host_to_pc.clock.next = self.bidi_clock.val();
         self.pc_to_host.clock.next = self.bidi_clock.val();
         self.bidi_dev.clock.next = self.bidi_clock.val();
